Name:           gmp-ecm
Version:        6.4.4
Release:        2%{?dist}
Summary:        Elliptic Curve Method for Integer Factorization
Group:          Applications/Engineering
License:        GPLv3+
URL:            https://gforge.inria.fr/projects/ecm/
Source0:        https://gforge.inria.fr/frs/download.php/32159/ecm-%{version}.tar.gz

BuildRequires:  docbook-style-xsl
BuildRequires:  gmp-devel
BuildRequires:  gsl-devel
BuildRequires:  libxslt
BuildRequires:  m4

Requires:       %{name}-libs%{?_isa} = %{version}-%{release}

%description
Programs and libraries employing elliptic curve method for factoring
integers (with GMP for arbitrary precision integers).


%package        devel
Summary:        Files useful for %{name} development
Group:          Development/Libraries
License:        LGPLv3+
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}
Requires:       gmp-devel%{?_isa}


%description    devel
The libraries and header files for using %{name} for development.


%package        libs
Summary:        Elliptic Curve Method library
Group:          System Environment/Libraries
License:        LGPLv3+


%description    libs
The %{name} library.


%package        static
Summary:        Files used for static linking with %{name}
Group:          Development/Libraries
License:        LGPLv3+
Requires:       %{name}-devel%{?_isa} = %{version}-%{release}


%description    static
The static libraries for using %{name} for development.


%prep
%setup -q -n ecm-%{version}

# Fix non-UTF-8 encodings
for badfile in ChangeLog README AUTHORS ; do
  iconv -f iso-8859-1 -t utf-8 -o $badfile.UTF-8 $badfile 
  touch -r $badfile $badfile.UTF-8
  mv $badfile.UTF-8 $badfile
done

# Fix the FSF's address
for badfile in `grep -FRl 'Fifth Floor' .`; do
  sed -e 's/Fifth Floor/Suite 500/' -e 's/02111-1307/02110-1335/' \
      -i.orig $badfile
  touch -r $badfile.orig $badfile
  rm -f $badfile.orig
done


%build
FLGS="--enable-shared --enable-openmp --disable-gmp-cflags"

# Build an SSE2-enabled version for 32-bit x86
%ifarch %{ix86}
%configure ${FLGS} --build=pentium4-pc-linux-gnu --host=pentium4-pc-linux-gnu \
  --disable-static --enable-sse2 \
  CFLAGS="$RPM_OPT_FLAGS -std=gnu99 -march=pentium4 -Wa,--noexecstack" \
  LDFLAGS="$RPM_LD_FLAGS -Wl,-z,noexecstack -lgmp -lgomp"

# Eliminate hardcoded rpaths
sed -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    -i libtool

rm -f ecm-params.h
ln -s ecm-params.h.pentium4 ecm-params.h
make %{?_smp_mflags}
cp -a .libs .sse2
make clean
# Make clean doesn't clean everything....
rm -f config.h config.log config.status ecm-params.h stamp-h1
ln -s ecm-params.h.default ecm-params.h
%endif

# Build a non-SSE2 version (x86_64 loses out; the assembly code containing
# SSE2 instructions is 32-bit only).
%configure ${FLGS} --disable-sse2 \
  CFLAGS="$RPM_OPT_FLAGS -std=gnu99 -Wa,--noexecstack" \
  LDFLAGS="$RPM_LD_FLAGS -Wl,-z,noexecstack -lgmp -lgomp"

# Eliminate hardcoded rpaths
sed -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    -i libtool

make --eval='.SECONDARY:' %{?_smp_mflags}


%install
make install DESTDIR=$RPM_BUILD_ROOT INSTALL="install -p"
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
pushd $RPM_BUILD_ROOT%{_bindir}
  mv ecm %{name}
popd
pushd $RPM_BUILD_ROOT%{_mandir}/man1
  for file in ecm.1*; do
    mv $file ${file/ecm/%{name}}
  done
popd

%ifarch %ix86
mkdir -p $RPM_BUILD_ROOT%{_libdir}/sse2
cp -p .sse2/libecm.so.0.0.0 $RPM_BUILD_ROOT%{_libdir}/sse2
%endif


%check
export LD_LIBRARY_PATH=`pwd`/.libs
make check


%post libs -p /sbin/ldconfig


%postun libs -p /sbin/ldconfig


%files
%doc COPYING README
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*


%files devel
%doc README.lib
%{_includedir}/ecm.h
%{_libdir}/libecm.so


%files libs
%doc COPYING.LIB AUTHORS ChangeLog NEWS TODO
%{_libdir}/libecm.so.*
%ifarch %ix86
%{_libdir}/sse2/libecm.so.*
%endif


%files static
%{_libdir}/libecm.a


%changelog
* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 6.4.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Mar  4 2013 Jerry James <loganjerry@gmail.com> - 6.4.4-1
- New upstream release
- Drop all patches; all were from upstream subversion and are now applied
- Workaround for bz 759376 no longer necessary

* Sat Feb 23 2013 Jerry James <loganjerry@gmail.com> - 6.4.3-2
- Add -gmp51 patch to deal with changes in GMP 5.1

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 6.4.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Fri Dec  7 2012 Jerry James <loganjerry@gmail.com> - 6.4.3-1
- New upstream release
- Fix PPC64 build (bz 804330)

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 6.4.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon Apr  2 2012 Jerry James <loganjerry@gmail.com> - 6.4.2-1
- New upstream release

* Mon Mar 19 2012 Jerry James <loganjerry@gmail.com> - 6.4.1-2
- Fix elimination of hardcoded rpaths
- Mark -devel and -static as LGPLv3+ as well

* Mon Mar 19 2012 Jerry James <loganjerry@gmail.com> - 6.4.1-1
- New upstream release
- Split library and binaries into separate packages for licensing reasons
- Disable broken shellcmd feature

* Mon Jan 23 2012 Jerry James <loganjerry@gmail.com> - 6.4-1
- New upstream release

* Sat Jan  7 2012 Jerry James <loganjerry@gmail.com> - 6.3-2
- Rebuild for GCC 4.7

* Fri Oct 21 2011 Marcela Mašláňová <mmaslano@redhat.com> - 6.3-1.2
- rebuild with new gmp without compat lib

* Tue Oct 11 2011 Peter Schiffer <pschiffe@redhat.com> - 6.3-1.1
- rebuild with new gmp

* Fri May 13 2011 Jerry James <loganjerry@gmail.com> - 6.3-1
- New upstream release
- Drop BuildRoot tag, clean script, and clean at start of install script
- Build an SSE2 version of the library for 32-bit x86
- Ensure the executable stack flag is not set on any ELF objects
- Various cleanups to fix rpmlint warnings
- Add check script

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 6.2.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 6.2.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Apr 30 2009 Conrad Meyer <konrad@tylerc.org> - 6.2.3-1
- Bump to 6.2.3.

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 6.2.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sun Nov 30 2008 Conrad Meyer <konrad@tylerc.org> - 6.2.1-4
- Convert AUTHORS to utf-8 as well.
- Really bump release this time.

* Sat Nov 29 2008 Conrad Meyer <konrad@tylerc.org> - 6.2.1-3
- Add some %%docs.
- Add ldconfig (oops).
- Install binary and manpage under gmp-ecm, not ecm.

* Fri Nov 28 2008 Conrad Meyer <konrad@tylerc.org> - 6.2.1-2
- Change name.
- Split out a -static package and build shared libs for -devel.

* Wed Nov 26 2008 Conrad Meyer <konrad@tylerc.org> - 6.2.1-1
- Initial package.
